==> drill-java-exec-1.6.0.jar: org/apache/drill/exec/expr/fn/impl/TimeIntervalYearFunctions.java <==

/*******************************************************************************

 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.drill.exec.expr.fn.impl;

import io.netty.buffer.ByteBuf;

import org.apache.drill.exec.expr.DrillSimpleFunc;
import org.apache.drill.exec.expr.annotations.FunctionTemplate;
import org.apache.drill.exec.expr.annotations.FunctionTemplate.NullHandling;
import org.apache.drill.exec.expr.annotations.Output;
import org.apache.drill.exec.expr.annotations.Param;
import org.apache.drill.exec.expr.annotations.Workspace;
import org.apache.drill.exec.expr.holders.*;
import org.apache.drill.exec.record.RecordBatch;
import org.joda.time.MutableDateTime;
import org.joda.time.DateTimeZone;
import org.joda.time.DateMidnight;
import org.apache.drill.exec.expr.fn.impl.DateUtility;

public class TimeIntervalYearFunctions {

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_add", "add"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class TimeIntervalYearAddFunction implements DrillSimpleFunc {
    @Param TimeHolder left;
    @Param IntervalYearHolder right;
    @Output TimeHolder out;

        public void setup() {
        }

        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_add", "add"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class IntervalYearTimeAddFunction implements DrillSimpleFunc {
    @Param IntervalYearHolder right;
    @Param TimeHolder left;
    @Output TimeHolder out;

        public void setup() {
        }
        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_sub", "subtract", "date_diff"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class TimeIntervalYearSubtractFunction implements DrillSimpleFunc {
    @Param TimeHolder left;
    @Param IntervalYearHolder right;
    @Output TimeHolder out;

        public void setup() {
        }

        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }
}

==> drill-java-exec-1.10.0.jar: org/apache/drill/exec/expr/fn/impl/TimeIntervalYearFunctions.java <==

/*******************************************************************************

 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.drill.exec.expr.fn.impl;

import io.netty.buffer.ByteBuf;

import org.apache.drill.exec.expr.DrillSimpleFunc;
import org.apache.drill.exec.expr.annotations.FunctionTemplate;
import org.apache.drill.exec.expr.annotations.FunctionTemplate.NullHandling;
import org.apache.drill.exec.expr.annotations.Output;
import org.apache.drill.exec.expr.annotations.Param;
import org.apache.drill.exec.expr.annotations.Workspace;
import org.apache.drill.exec.expr.holders.*;
import org.apache.drill.exec.record.RecordBatch;
import org.joda.time.MutableDateTime;
import org.joda.time.DateTimeZone;
import org.joda.time.DateMidnight;
import org.apache.drill.exec.expr.fn.impl.DateUtility;

/*
 * This class is generated using freemarker and the DateIntervalFunctionTemplates/DateIntervalArithmeticFunctions.java template.
 */

public class TimeIntervalYearFunctions {

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_add", "add"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class TimeIntervalYearAddFunction implements DrillSimpleFunc {
    @Param TimeHolder left;
    @Param IntervalYearHolder right;
    @Output TimeHolder out;

        public void setup() {
        }

        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_add", "add"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class IntervalYearTimeAddFunction implements DrillSimpleFunc {
    @Param IntervalYearHolder right;
    @Param TimeHolder left;
    @Output TimeHolder out;

        public void setup() {
        }
        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }

    @SuppressWarnings("unused")
    @FunctionTemplate(names = {"date_sub", "subtract", "date_diff"}, scope = FunctionTemplate.FunctionScope.SIMPLE, nulls=NullHandling.NULL_IF_NULL)
    public static class TimeIntervalYearSubtractFunction implements DrillSimpleFunc {
    @Param TimeHolder left;
    @Param IntervalYearHolder right;
    @Output TimeHolder out;

        public void setup() {
        }

        public void eval() {
    // Needn't add anything to time from interval year data type. Output is same as input
    out.value = left.value;
        }
    }
}
